package com.cicdi.notify.sms.telecom;

import com.cicdi.notify.*;
import com.cicdi.notify.sms.SmsProvider;
import com.cicdi.notify.template.TemplateManager;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Map;
import java.util.Objects;

/**
 * @author xueye
 */
public class TelecomSmsNotifier extends AbstractNotifier<TelecomSmsTemplate> {

    private String serviceUrl;
    private String userId;
    private String password;

    private String notifierId;

    public TelecomSmsNotifier(NotifierProperties properties, TemplateManager templateManager) {
        super(templateManager);
        Map<String, Object> configuration = properties.getConfiguration();
        this.serviceUrl = (String) Objects.requireNonNull(configuration.get("serviceUrl"), "serviceUrl不能为空");
        this.userId = (String) Objects.requireNonNull(configuration.get("userId"), "userId不能为空");
        this.password = (String) Objects.requireNonNull(configuration.get("password"), "password不能为空");
        this.notifierId = properties.getId();
    }

    @Override
    public String getNotifierId() {
        return null;
    }

    @Override
    public NotifyType getType() {
        return DefaultNotifyType.sms;
    }

    @Override
    public Provider getProvider() {
        return SmsProvider.telecom;
    }

    @Override
    public void send(TelecomSmsTemplate template, Map<String, Object> context) {
        try {
            URL obj = new URL(serviceUrl);
            HttpURLConnection con = (HttpURLConnection) obj.openConnection();

            //添加请求头
            con.setRequestMethod("POST");
//            con.setRequestProperty("User-Agent", USER_AGENT);
            con.setRequestProperty("Accept-Language", "en-US,en;q=0.5");

            String urlParameters = "userId=" +
                    userId +
                    "&password=" +
                    password +
                    "&content=" +
                    template.getText() +
                    "&mobile=" +
                    template.getMobile();

            //发送Post请求
            con.setDoOutput(true);
            DataOutputStream wr = new DataOutputStream(con.getOutputStream());
            wr.writeBytes(urlParameters);
            wr.flush();
            wr.close();

            int responseCode = con.getResponseCode();
            System.out.println("\nSending 'POST' request to URL : " + serviceUrl);
            System.out.println("Post parameters : " + urlParameters);
            System.out.println("Response Code : " + responseCode);

            BufferedReader in = new BufferedReader(
                    new InputStreamReader(con.getInputStream()));
            String inputLine;
            StringBuffer response = new StringBuffer();

            while ((inputLine = in.readLine()) != null) {
                response.append(inputLine);
            }
            in.close();

            //打印结果
            System.out.println(response.toString());
        } catch (Exception e) {

        }
    }

    @Override
    public void close() {

    }
}
